@@ -134,6 +134,17 @@ if hasattr( pysvn.wc_notify_action, 'exists' ):
     wc_notify_action_map[ pysvn.wc_notify_action.update_replace ] = 'update_replace'
 
 
+if hasattr( pysvn.wc_notify_action, 'property_added' ):
+    wc_notify_action_map[ pysvn.wc_notify_action.property_added ] = 'property_added'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_modified ] = 'property_modified'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_deleted ] = 'property_deleted'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_deleted_nonexistent ] = 'property_deleted_nonexistent'
+    wc_notify_action_map[ pysvn.wc_notify_action.revprop_set ] = 'revprop_set'
+    wc_notify_action_map[ pysvn.wc_notify_action.revprop_deleted ] = 'revprop_deleted'
+    wc_notify_action_map[ pysvn.wc_notify_action.merge_completed ] = 'merge_completed'
+    wc_notify_action_map[ pysvn.wc_notify_action.tree_conflict ] = 'tree_conflict'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_external ] = 'failed_external'
+
 class SvnCommand:
     def __init__( self, progname ):
         self.progname = progname
@@ -154,6 +165,9 @@ class SvnCommand:
         self.client.callback_get_log_message = self.callback_getLogMessage
         self.client.callback_notify = self.callback_notify
         self.client.callback_cancel = self.callback_cancel
+        if hasattr( self.client, 'callback_conflict_resolver' ):
+            self.client.callback_conflict_resolver = self.callback_conflict_resolver
+        self.client.callback_cancel = self.callback_cancel
         self.client.callback_ssl_client_cert_password_prompt = self.callback_ssl_client_cert_password_prompt
         self.client.callback_ssl_client_cert_prompt = self.callback_ssl_client_cert_prompt
         self.client.callback_ssl_server_prompt = self.callback_ssl_server_prompt
@@ -195,6 +209,13 @@ class SvnCommand:
             else:
                 print( msg )
 
+    def callback_conflict_resolver( self, arg_dict ):
+        print( 'callback_conflict_resolver' )
+        for key in sorted( arg_dict.keys() ):
+            print( '  %s: %r' % (key, arg_dict[ key ]) )
+
+        return pysvn.wc_conflict_choice.postpone, None, False
+
     def callback_getLogin( self, realm, username, may_save ):
         print( 'May save: %s ' % may_save )
         print( 'Realm: %s ' % realm )
@@ -261,11 +282,11 @@ class SvnCommand:
             self.notify_message_list = []
 
     def cmd_version( self, args ):
-        print( 'PYSVN Version: %s' % pysvn.version )
-        print( 'SVN Version: %s' % pysvn.svn_version )
+        print( 'PYSVN Version: %r' % (pysvn.version,) )
+        print( 'SVN Version: %r' % (pysvn.svn_version,) )
         if hasattr( pysvn, 'svn_api_version' ):
-            print( 'SVN API Version: %s' % pysvn.svn_api_version )
-        print( 'pysvn._pysvn %s' % pysvn._pysvn )
+            print( 'SVN API Version: %r' % (pysvn.svn_api_version,) )
+        print( 'pysvn._pysvn %r' % (pysvn._pysvn,) )
 
 
     def cmd_is_url( self, args ):
@@ -385,7 +406,6 @@ class SvnCommand:
             print( 'No tmp dir!' )
             return
 
-        tmpdir = os.path.join( tmpdir, 'svn_tmp' )
         self.debug( 'cmd_diff %r, %r, %r, %r, %r' % (tmpdir, positional_args[0], recurse, revision1, revision2) )
         diff_text = self.client.diff( tmpdir, positional_args[0], recurse=recurse,
                                             revision1=revision1, revision2=revision2,
