@@ -62,6 +62,10 @@ public:     // data
 #if defined( PYSVN_HAS_CONTEXT_PROGRESS )
     Py::Object  m_pyfn_Progress;
 #endif
+#if defined( PYSVN_HAS_SVN_CLIENT_CTX_T__CONFLICT_FUNC )
+    Py::Object  m_pyfn_ConflictResolver;
+#endif
+
     Py::Object  m_pyfn_Cancel;
     Py::Object  m_pyfn_GetLogMessage;
     Py::Object  m_pyfn_SslServerPrompt;
@@ -119,6 +123,16 @@ private:    // methods
         );
 #endif
 
+#if defined( PYSVN_HAS_SVN_CLIENT_CTX_T__CONFLICT_FUNC )
+    bool contextConflictResolver
+        (
+        svn_wc_conflict_result_t **result,
+        const svn_wc_conflict_description_t *description,
+        apr_pool_t *pool
+        );
+#endif
+
+
     //
     // this method will be called periodically to allow
     // the app to cancel long running operations
@@ -425,7 +439,7 @@ public:
     svn_opt_revision_t getRevision( const char *name, svn_opt_revision_t default_value );
 
 #if defined( PYSVN_HAS_SVN__DEPTH_PARAMETER )
-    svn_depth_t getDepth( const char *depth_name, const char *recursive_name, svn_depth_t default_value, svn_depth_t recursive_false_value=svn_depth_files );
+    svn_depth_t getDepth( const char *depth_name, const char *recursive_name, svn_depth_t default_value, svn_depth_t recursive_true_value, svn_depth_t recursive_false_value );
     svn_depth_t getDepth( const char *depth_name, svn_depth_t default_value );
     svn_depth_t getDepth( const char *depth_name );
 #endif
