@@ -31,6 +31,7 @@ PYSVN_STATIC_STRING( name_callback_get_log_message, "callback_get_log_message" )
 PYSVN_STATIC_STRING( name_callback_get_login, "callback_get_login" )
 PYSVN_STATIC_STRING( name_callback_notify, "callback_notify" )
 PYSVN_STATIC_STRING( name_callback_progress, "callback_progress" )
+PYSVN_STATIC_STRING( name_callback_conflict_resolver, "callback_conflict_resolver" )
 PYSVN_STATIC_STRING( name_callback_ssl_client_cert_password_prompt, "callback_ssl_client_cert_password_prompt" )
 PYSVN_STATIC_STRING( name_callback_ssl_client_cert_prompt, "callback_ssl_client_cert_prompt" )
 PYSVN_STATIC_STRING( name_callback_ssl_server_prompt, "callback_ssl_server_prompt" )
@@ -132,6 +133,7 @@ PYSVN_STATIC_STRING( name_result_wrappers, "result_wrappers" )
 PYSVN_STATIC_STRING( name_copy_info, "copy_info" )
 
 PYSVN_STATIC_PY_STRING_P( py_name_callback_cancel )
+PYSVN_STATIC_PY_STRING_P( py_name_callback_conflict_resolver )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_get_log_message )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_get_login )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_notify )
